@@ -1,6 +1,6 @@
 ;;; ebdb-migrate.el --- Migration/upgrade functions for EBDB  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2020  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2023  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -493,10 +493,19 @@ BBDB sets the default of that option."
     (when phone
       (dolist (p phone)
 	(let ((label (aref p 0))
-	      instance)
+	      instance comment)
 	  (setq instance
 		(if (= 2 (length p))
-		    (ebdb-parse ebdb-default-phone-class (aref p 1))
+		    ;; BBDB let users put arbitrary strings in after
+		    ;; the phone number, when the number itself was a
+		    ;; plain string.  Pull that out and put it in the
+		    ;; `comment' slot.
+		    (let ((p-string (aref p 1)))
+		      (if (null (string-match "\\([^[:digit:]]+\\)\\'" p-string))
+			  (ebdb-parse ebdb-default-phone-class p-string)
+			(setq comment (string-trim (match-string 1 p-string)))
+			(ebdb-parse ebdb-default-phone-class
+				    (substring p-string 0 (match-beginning 1)))))
 		  (make-instance ebdb-default-phone-class
 				 :area-code (ebdb-vphone-area p)
 				 :number (replace-regexp-in-string
@@ -505,6 +514,8 @@ BBDB sets the default of that option."
 						     (ebdb-vphone-exchange p)
 						     (ebdb-vphone-suffix p)))
 				 :extension (ebdb-vphone-extension p))))
+	  (when comment
+	    (setf (slot-value instance 'comment) comment))
 	  (setf (slot-value instance 'label) label)
 	  (when (and (null (slot-value instance 'country-code))
 		     ebdb-default-phone-country)
@@ -660,7 +671,7 @@ BBDB sets the default of that option."
           (setq migrate (< file-format ebdb-file-format)))
 	(unless (re-search-forward "^\\[" nil t)
 	  (error "Unreadabe BBDB file: no contacts found"))
-	(goto-char (point-at-bol))
+	(goto-char (line-beginning-position))
         ;; narrow the buffer to skip over the rubbish before the first record.
         (narrow-to-region (point) (point-max))
         (let ((modp (buffer-modified-p))
