@@ -1,6 +1,6 @@
 ;;; ebdb-vm.el --- EBDB interface to VM              -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2017  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2023  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -118,26 +118,22 @@ the value of `ebdb-default-window-size'."
 (defcustom ebdb/vm-auto-folder-headers '("From:" "To:" "CC:")
   "The headers used by `ebdb/vm-auto-folder'.
 The order in this list is the order how matching will be performed."
-  :group 'ebdb-mua-vm
   :type '(repeat (string :tag "header name")))
 
 ;;;###autoload
 (defcustom ebdb/vm-auto-folder-field "vm-folder"
   "The xfield which `ebdb/vm-auto-folder' searches for."
-  :group 'ebdb-mua-vm
   :type 'symbol)
 
 ;;;###autoload
 (defcustom ebdb/vm-virtual-folder-field "vm-virtual"
   "The xfield which `ebdb/vm-virtual-folder' searches for."
-  :group 'ebdb-mua-vm
   :type 'symbol)
 
 ;;;###autoload
 (defcustom ebdb/vm-virtual-real-folders nil
   "Real folders used for defining virtual folders.
 If nil use `vm-primary-inbox'."
-  :group 'ebdb-mua-vm
   :type '(choice (const :tag "Use vm-primary-inbox" nil)
                  (repeat (string :tag "Real folder"))))
 
@@ -255,16 +251,14 @@ Its elements may be strings used both as the field value to check for
 and as the label to apply to the message.
 If an element is a cons pair (VALUE . LABEL), VALUE is the field value
 to search for and LABEL is the label to apply."
-  :group 'ebdb-mua-vm
-  :type 'list)
+  :type '(repeat string))
 
 (defcustom ebdb/vm-auto-add-label-field 'ebdb-mail-alias-field
   "Fields used by `ebdb/vm-auto-add-label' to automatically label messages.
 This is either a single EBDB field or a list of fields that
 `ebdb/vm-auto-add-label' uses to check for labels to apply to a message.
 Defaults to `ebdb-mail-alias-field' which defaults to `mail-alias'."
-  :group 'ebdb-mua-vm
-  :type '(choice symbol list))
+  :type '(choice symbol (repeat symbol)))
 
 (defun ebdb/vm-auto-add-label (record)
   "Automatically add labels to VM messages.
@@ -310,7 +304,7 @@ from different senders."
                             ebdb/vm-auto-add-label-list))))
         (if labels
             (vm-add-message-labels
-             (mapconcat 'identity labels " ") 1)))))
+             (mapconcat #'identity labels " ") 1)))))
 
 
 
@@ -369,12 +363,14 @@ from different senders."
 ;;;###autoload
 (defun ebdb-insinuate-vm ()
   "Hook EBDB into VM."
+  (unless ebdb-db-list
+    (ebdb-load))
   (define-key vm-mode-map ";" ebdb-mua-keymap)
-  (define-key vm-mode-map "/" 'ebdb)
+  (define-key vm-mode-map "/" #'ebdb)
   ;; `mail-mode-map' is the parent of `vm-mail-mode-map'.
   ;; So the following is also done by `ebdb-insinuate-mail'.
   (if (and ebdb-complete-mail (boundp 'vm-mail-mode-map))
-      (define-key vm-mail-mode-map "\M-\t" 'ebdb-complete-mail))
+      (define-key vm-mail-mode-map "\M-\t" #'ebdb-complete-mail))
 
   ;; Set up user field for use in `vm-summary-format'
   ;; (1) Big solution: use whole name
@@ -399,6 +395,7 @@ from different senders."
             ;; the EBDB record of the sender.
             (lambda (m) (ebdb-mua-summary-mark (vm-su-from m))))))
 
+;;;###autoload
 (defun ebdb-vm-auto-update ()
   (ebdb-mua-auto-update ebdb-vm-auto-update-p))
 
